/*******************************************************************************
* File Name: SCBUART.c
* Version 1.20
*
* Description:
*  This file provides the source code to the API for the SCB Component.
*
* Note:
*
*******************************************************************************
* Copyright 2013-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "SCBUART_PVT.h"

#if(SCBUART_SCB_MODE_I2C_INC)
    #include "SCBUART_I2C_PVT.h"
#endif /* (SCBUART_SCB_MODE_I2C_INC) */

#if(SCBUART_SCB_MODE_EZI2C_INC)
    #include "SCBUART_EZI2C_PVT.h"
#endif /* (SCBUART_SCB_MODE_EZI2C_INC) */

#if(SCBUART_SCB_MODE_SPI_INC || SCBUART_SCB_MODE_UART_INC)
    #include "SCBUART_SPI_UART_PVT.h"
#endif /* (SCBUART_SCB_MODE_SPI_INC || SCBUART_SCB_MODE_UART_INC) */


/***************************************
*    Run Time Configuration Vars
***************************************/

/* Stores internal component configuration for unconfigured mode */
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Common config vars */
    uint8 SCBUART_scbMode = SCBUART_SCB_MODE_UNCONFIG;
    uint8 SCBUART_scbEnableWake;
    uint8 SCBUART_scbEnableIntr;

    /* I2C config vars */
    uint8 SCBUART_mode;
    uint8 SCBUART_acceptAddr;

    /* SPI/UART config vars */
    volatile uint8 * SCBUART_rxBuffer;
    uint8  SCBUART_rxDataBits;
    uint32 SCBUART_rxBufferSize;

    volatile uint8 * SCBUART_txBuffer;
    uint8  SCBUART_txDataBits;
    uint32 SCBUART_txBufferSize;

    /* EZI2C config vars */
    uint8 SCBUART_numberOfAddr;
    uint8 SCBUART_subAddrSize;
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */


/***************************************
*     Common SCB Vars
***************************************/

uint8 SCBUART_initVar = 0u;

#if !defined (CY_REMOVE_SCBUART_CUSTOM_INTR_HANDLER)
    cyisraddress SCBUART_customIntrHandler = NULL;
#endif /* !defined (CY_REMOVE_SCBUART_CUSTOM_INTR_HANDLER) */


/***************************************
*    Private Function Prototypes
***************************************/

static void SCBUART_ScbEnableIntr(void);
static void SCBUART_ScbModeStop(void);


/*******************************************************************************
* Function Name: SCBUART_Init
********************************************************************************
*
* Summary:
*  Initializes the SCB component to operate in one of the selected configurations:
*  I2C, SPI, UART or EZ I2C.
*  When the configuration is set to Unconfigured SCB, this function does
*  not do any initialization. Use mode-specific initialization APIs instead:
*  SCB_I2CInit, SCB_SpiInit, SCB_UartInit or SCB_EzI2CInit.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCBUART_Init(void)
{
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    if(SCBUART_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        SCBUART_initVar = 0u; /* Clear init var */
    }
    else
    {
        /* Initialization was done before call */
    }

#elif(SCBUART_SCB_MODE_I2C_CONST_CFG)
    SCBUART_I2CInit();

#elif(SCBUART_SCB_MODE_SPI_CONST_CFG)
    SCBUART_SpiInit();

#elif(SCBUART_SCB_MODE_UART_CONST_CFG)
    SCBUART_UartInit();

#elif(SCBUART_SCB_MODE_EZI2C_CONST_CFG)
    SCBUART_EzI2CInit();

#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: SCBUART_Enable
********************************************************************************
*
* Summary:
*  Enables the SCB component operation.
*  The SCB configuration should be not changed when the component is enabled.
*  Any configuration changes should be made after disabling the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCBUART_Enable(void)
{
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    /* Enable SCB block, only if it is already configured */
    if(!SCBUART_SCB_MODE_UNCONFIG_RUNTM_CFG)
    {
        SCBUART_CTRL_REG |= SCBUART_CTRL_ENABLED;

        SCBUART_ScbEnableIntr();
    }
#else
    SCBUART_CTRL_REG |= SCBUART_CTRL_ENABLED;

    SCBUART_ScbEnableIntr();
#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


/*******************************************************************************
* Function Name: SCBUART_Start
********************************************************************************
*
* Summary:
*  Invokes SCB_Init() and SCB_Enable().
*  After this function call, the component is enabled and ready for operation.
*  When configuration is set to Unconfigured SCB, the component must first be
*  initialized to operate in one of the following configurations: I2C, SPI, UART
*  or EZ I2C. Otherwise this function does not enable the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  SCBUART_initVar - used to check initial configuration, modified
*  on first function call.
*
*******************************************************************************/
void SCBUART_Start(void)
{
    if(0u == SCBUART_initVar)
    {
        SCBUART_Init();
        SCBUART_initVar = 1u; /* Component was initialized */
    }

    SCBUART_Enable();
}


/*******************************************************************************
* Function Name: SCBUART_Stop
********************************************************************************
*
* Summary:
*  Disables the SCB component and its interrupt.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void SCBUART_Stop(void)
{
#if(SCBUART_SCB_IRQ_INTERNAL)
    SCBUART_DisableInt();
#endif /* (SCBUART_SCB_IRQ_INTERNAL) */

    SCBUART_CTRL_REG &= (uint32) ~SCBUART_CTRL_ENABLED;  /* Disable SCB block */

#if(SCBUART_SCB_IRQ_INTERNAL)
    SCBUART_ClearPendingInt();
#endif /* (SCBUART_SCB_IRQ_INTERNAL) */

    SCBUART_ScbModeStop(); /* Calls scbMode specific Stop function */
}


/*******************************************************************************
* Function Name: SCBUART_SetCustomInterruptHandler
********************************************************************************
*
* Summary:
*  Registers a function to be called by the internal interrupt handler.
*  First the function that is registered is called, then the internal interrupt
*  handler performs any operations such as software buffer management functions
*  before the interrupt returns.  It is the user's responsibility not to break the
*  software buffer operations. Only one custom handler is supported, which is
*  the function provided by the most recent call.
*  At initialization time no custom handler is registered.
*
* Parameters:
*  func: Pointer to the function to register.
*        The value NULL indicates to remove the current custom interrupt
*        handler.
*
* Return:
*  None
*
*******************************************************************************/
void SCBUART_SetCustomInterruptHandler(cyisraddress func)
{
#if !defined (CY_REMOVE_SCBUART_CUSTOM_INTR_HANDLER)
    SCBUART_customIntrHandler = func; /* Register interrupt handler */
#else
    if(NULL != func)
    {
        /* Suppress compiler warning */
    }
#endif /* !defined (CY_REMOVE_SCBUART_CUSTOM_INTR_HANDLER) */
}


/*******************************************************************************
* Function Name: SCBUART_ScbModeEnableIntr
********************************************************************************
*
* Summary:
*  Enables an interrupt for a specific mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static void SCBUART_ScbEnableIntr(void)
{
#if(SCBUART_SCB_IRQ_INTERNAL)
    #if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
        /* Enable interrupt in the NVIC */
        if(0u != SCBUART_scbEnableIntr)
        {
            SCBUART_EnableInt();
        }
    #else
        SCBUART_EnableInt();

    #endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */
#endif /* (SCBUART_SCB_IRQ_INTERNAL) */
}


/*******************************************************************************
* Function Name: SCBUART_ScbModeStop
********************************************************************************
*
* Summary:
*  Calls the Stop function for a specific operation mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
static void SCBUART_ScbModeStop(void)
{
#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    if(SCBUART_SCB_MODE_I2C_RUNTM_CFG)
    {
        SCBUART_I2CStop();
    }
    else if(SCBUART_SCB_MODE_EZI2C_RUNTM_CFG)
    {
        SCBUART_EzI2CStop();
    }
    else
    {
        /* Do nohing for other modes */
    }
#elif(SCBUART_SCB_MODE_I2C_CONST_CFG)
    SCBUART_I2CStop();

#elif(SCBUART_SCB_MODE_EZI2C_CONST_CFG)
    SCBUART_EzI2CStop();

#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */
}


#if(SCBUART_SCB_MODE_UNCONFIG_CONST_CFG)
    /*******************************************************************************
    * Function Name: SCBUART_SetPins
    ********************************************************************************
    *
    * Summary:
    *  Sets the pins settings accordingly to the selected operation mode.
    *  Only available in the Unconfigured operation mode. The mode specific
    *  initialization function calls it.
    *  Pins configuration is set by PSoC Creator when a specific mode of operation
    *  is selected in design time.
    *
    * Parameters:
    *  mode:      Mode of SCB operation.
    *  subMode:   Sub-mode of SCB operation. It is only required for SPI and UART
    *             modes.
    *  uartTxRx:  Direction for UART.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void SCBUART_SetPins(uint32 mode, uint32 subMode, uint32 uartTxRx)
    {
        uint32 hsiomSel [SCBUART_SCB_PINS_NUMBER];
        uint32 pinsDm   [SCBUART_SCB_PINS_NUMBER];
        uint32 pinsInBuf = 0u;

        uint32 i;

        /* Set default HSIOM to GPIO and Drive Mode to Analog Hi-Z */
        for(i = 0u; i < SCBUART_SCB_PINS_NUMBER; i++)
        {
            hsiomSel[i]  = SCBUART_HSIOM_DEF_SEL;
            pinsDm[i]    = SCBUART_PIN_DM_ALG_HIZ;
        }

        if((SCBUART_SCB_MODE_I2C   == mode) ||
           (SCBUART_SCB_MODE_EZI2C == mode))
        {
            hsiomSel[SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_HSIOM_I2C_SEL;
            hsiomSel[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_HSIOM_I2C_SEL;

            pinsDm[SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_PIN_DM_OD_LO;
            pinsDm[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_PIN_DM_OD_LO;
        }
    #if(!SCBUART_CY_SCBIP_V1_I2C_ONLY)
        else if(SCBUART_SCB_MODE_SPI == mode)
        {
            hsiomSel[SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
            hsiomSel[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
            hsiomSel[SCBUART_SCLK_PIN_INDEX]        = SCBUART_HSIOM_SPI_SEL;

            if(SCBUART_SPI_SLAVE == subMode)
            {
                /* Slave */
                pinsDm[SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_PIN_DM_DIG_HIZ;
                pinsDm[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_PIN_DM_STRONG;
                pinsDm[SCBUART_SCLK_PIN_INDEX]        = SCBUART_PIN_DM_DIG_HIZ;

            #if(SCBUART_SS0_PIN)
                /* Only SS0 is valid choice for Slave */
                hsiomSel[SCBUART_SS0_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
                pinsDm  [SCBUART_SS0_PIN_INDEX] = SCBUART_PIN_DM_DIG_HIZ;
            #endif /* (SCBUART_SS1_PIN) */

            #if(SCBUART_MISO_SDA_TX_PIN)
                /* Disable input buffer */
                 pinsInBuf |= SCBUART_MISO_SDA_TX_PIN_MASK;
            #endif /* (SCBUART_MISO_SDA_TX_PIN_PIN) */
            }
            else /* (Master) */
            {
                pinsDm[SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_PIN_DM_STRONG;
                pinsDm[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_PIN_DM_DIG_HIZ;
                pinsDm[SCBUART_SCLK_PIN_INDEX]        = SCBUART_PIN_DM_STRONG;

            #if(SCBUART_SS0_PIN)
                hsiomSel [SCBUART_SS0_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
                pinsDm   [SCBUART_SS0_PIN_INDEX] = SCBUART_PIN_DM_STRONG;
                pinsInBuf                                |= SCBUART_SS0_PIN_MASK;
            #endif /* (SCBUART_SS0_PIN) */

            #if(SCBUART_SS1_PIN)
                hsiomSel [SCBUART_SS1_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
                pinsDm   [SCBUART_SS1_PIN_INDEX] = SCBUART_PIN_DM_STRONG;
                pinsInBuf                                |= SCBUART_SS1_PIN_MASK;
            #endif /* (SCBUART_SS1_PIN) */

            #if(SCBUART_SS2_PIN)
                hsiomSel [SCBUART_SS2_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
                pinsDm   [SCBUART_SS2_PIN_INDEX] = SCBUART_PIN_DM_STRONG;
                pinsInBuf                                |= SCBUART_SS2_PIN_MASK;
            #endif /* (SCBUART_SS2_PIN) */

            #if(SCBUART_SS3_PIN)
                hsiomSel [SCBUART_SS3_PIN_INDEX] = SCBUART_HSIOM_SPI_SEL;
                pinsDm   [SCBUART_SS3_PIN_INDEX] = SCBUART_PIN_DM_STRONG;
                pinsInBuf                                |= SCBUART_SS3_PIN_MASK;
            #endif /* (SCBUART_SS2_PIN) */

                /* Disable input buffers */
            #if(SCBUART_MOSI_SCL_RX_PIN)
                pinsInBuf |= SCBUART_MOSI_SCL_RX_PIN_MASK;
            #endif /* (SCBUART_MOSI_SCL_RX_PIN) */

             #if(SCBUART_MOSI_SCL_RX_WAKE_PIN)
                pinsInBuf |= SCBUART_MOSI_SCL_RX_WAKE_PIN_MASK;
            #endif /* (SCBUART_MOSI_SCL_RX_WAKE_PIN) */

            #if(SCBUART_SCLK_PIN)
                pinsInBuf |= SCBUART_SCLK_PIN_MASK;
            #endif /* (SCBUART_SCLK_PIN) */
            }
        }
        else /* UART */
        {
            if(SCBUART_UART_MODE_SMARTCARD == subMode)
            {
                /* SmartCard */
                hsiomSel[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_HSIOM_UART_SEL;
                pinsDm  [SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_PIN_DM_OD_LO;
            }
            else /* Standard or IrDA */
            {
                if(0u != (SCBUART_UART_RX & uartTxRx))
                {
                    hsiomSel[SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_HSIOM_UART_SEL;
                    pinsDm  [SCBUART_MOSI_SCL_RX_PIN_INDEX] = SCBUART_PIN_DM_DIG_HIZ;
                }

                if(0u != (SCBUART_UART_TX & uartTxRx))
                {
                    hsiomSel[SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_HSIOM_UART_SEL;
                    pinsDm  [SCBUART_MISO_SDA_TX_PIN_INDEX] = SCBUART_PIN_DM_STRONG;

                #if(SCBUART_MISO_SDA_TX_PIN)
                     pinsInBuf |= SCBUART_MISO_SDA_TX_PIN_MASK;
                #endif /* (SCBUART_MISO_SDA_TX_PIN_PIN) */
                }
            }
        }
    #endif /* (!SCBUART_CY_SCBIP_V1_I2C_ONLY) */

    /* Configure pins: set HSIOM, DM and InputBufEnable */
    /* Note: the DR register settigns do not effect the pin output if HSIOM is other than GPIO */

    #if(SCBUART_MOSI_SCL_RX_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_MOSI_SCL_RX_HSIOM_REG,
                                       SCBUART_MOSI_SCL_RX_HSIOM_MASK,
                                       SCBUART_MOSI_SCL_RX_HSIOM_POS,
                                       hsiomSel[SCBUART_MOSI_SCL_RX_PIN_INDEX]);

        SCBUART_spi_mosi_i2c_scl_uart_rx_SetDriveMode((uint8) pinsDm[SCBUART_MOSI_SCL_RX_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_mosi_i2c_scl_uart_rx_INP_DIS,
                                     SCBUART_spi_mosi_i2c_scl_uart_rx_MASK,
                                     (0u != (pinsInBuf & SCBUART_MOSI_SCL_RX_PIN_MASK)));
    #endif /* (SCBUART_MOSI_SCL_RX_PIN) */

    #if(SCBUART_MOSI_SCL_RX_WAKE_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_MOSI_SCL_RX_WAKE_HSIOM_REG,
                                       SCBUART_MOSI_SCL_RX_WAKE_HSIOM_MASK,
                                       SCBUART_MOSI_SCL_RX_WAKE_HSIOM_POS,
                                       hsiomSel[SCBUART_MOSI_SCL_RX_WAKE_PIN_INDEX]);

        SCBUART_spi_mosi_i2c_scl_uart_rx_wake_SetDriveMode((uint8)
                                                               pinsDm[SCBUART_MOSI_SCL_RX_WAKE_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_mosi_i2c_scl_uart_rx_wake_INP_DIS,
                                     SCBUART_spi_mosi_i2c_scl_uart_rx_wake_MASK,
                                     (0u != (pinsInBuf & SCBUART_MOSI_SCL_RX_WAKE_PIN_MASK)));

         /* Set interrupt on falling edge */
        SCBUART_SET_INCFG_TYPE(SCBUART_MOSI_SCL_RX_WAKE_INTCFG_REG,
                                        SCBUART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_MASK,
                                        SCBUART_MOSI_SCL_RX_WAKE_INTCFG_TYPE_POS,
                                        SCBUART_INTCFG_TYPE_FALLING_EDGE);
    #endif /* (SCBUART_MOSI_SCL_RX_WAKE_PIN) */

    #if(SCBUART_MISO_SDA_TX_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_MISO_SDA_TX_HSIOM_REG,
                                       SCBUART_MISO_SDA_TX_HSIOM_MASK,
                                       SCBUART_MISO_SDA_TX_HSIOM_POS,
                                       hsiomSel[SCBUART_MISO_SDA_TX_PIN_INDEX]);

        SCBUART_spi_miso_i2c_sda_uart_tx_SetDriveMode((uint8) pinsDm[SCBUART_MISO_SDA_TX_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_miso_i2c_sda_uart_tx_INP_DIS,
                                     SCBUART_spi_miso_i2c_sda_uart_tx_MASK,
                                    (0u != (pinsInBuf & SCBUART_MISO_SDA_TX_PIN_MASK)));
    #endif /* (SCBUART_MOSI_SCL_RX_PIN) */

    #if(SCBUART_SCLK_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_SCLK_HSIOM_REG, SCBUART_SCLK_HSIOM_MASK,
                                       SCBUART_SCLK_HSIOM_POS, hsiomSel[SCBUART_SCLK_PIN_INDEX]);

        SCBUART_spi_sclk_SetDriveMode((uint8) pinsDm[SCBUART_SCLK_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_sclk_INP_DIS,
                             SCBUART_spi_sclk_MASK,
                            (0u != (pinsInBuf & SCBUART_SCLK_PIN_MASK)));
    #endif /* (SCBUART_SCLK_PIN) */

    #if(SCBUART_SS0_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_SS0_HSIOM_REG, SCBUART_SS0_HSIOM_MASK,
                                       SCBUART_SS0_HSIOM_POS, hsiomSel[SCBUART_SS0_PIN_INDEX]);

        SCBUART_spi_ss0_SetDriveMode((uint8) pinsDm[SCBUART_SS0_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_ss0_INP_DIS,
                                     SCBUART_spi_ss0_MASK,
                                     (0u != (pinsInBuf & SCBUART_SS0_PIN_MASK)));
    #endif /* (SCBUART_SS1_PIN) */

    #if(SCBUART_SS1_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_SS1_HSIOM_REG, SCBUART_SS1_HSIOM_MASK,
                                       SCBUART_SS1_HSIOM_POS, hsiomSel[SCBUART_SS1_PIN_INDEX]);

        SCBUART_spi_ss1_SetDriveMode((uint8) pinsDm[SCBUART_SS1_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_ss1_INP_DIS,
                                     SCBUART_spi_ss1_MASK,
                                     (0u != (pinsInBuf & SCBUART_SS1_PIN_MASK)));
    #endif /* (SCBUART_SS1_PIN) */

    #if(SCBUART_SS2_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_SS2_HSIOM_REG, SCBUART_SS2_HSIOM_MASK,
                                       SCBUART_SS2_HSIOM_POS, hsiomSel[SCBUART_SS2_PIN_INDEX]);

        SCBUART_spi_ss2_SetDriveMode((uint8) pinsDm[SCBUART_SS2_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_ss2_INP_DIS,
                                     SCBUART_spi_ss2_MASK,
                                     (0u != (pinsInBuf & SCBUART_SS2_PIN_MASK)));
    #endif /* (SCBUART_SS2_PIN) */

    #if(SCBUART_SS3_PIN)
        SCBUART_SET_HSIOM_SEL(SCBUART_SS3_HSIOM_REG,  SCBUART_SS3_HSIOM_MASK,
                                       SCBUART_SS3_HSIOM_POS, hsiomSel[SCBUART_SS3_PIN_INDEX]);

        SCBUART_spi_ss3_SetDriveMode((uint8) pinsDm[SCBUART_SS3_PIN_INDEX]);

        SCBUART_SET_INP_DIS(SCBUART_spi_ss3_INP_DIS,
                                     SCBUART_spi_ss3_MASK,
                                     (0u != (pinsInBuf & SCBUART_SS3_PIN_MASK)));
    #endif /* (SCBUART_SS3_PIN) */
    }

#endif /* (SCBUART_SCB_MODE_UNCONFIG_CONST_CFG) */


/* [] END OF FILE */
